@@ -14,17 +14,18 @@ use File::Copy;
 use File::Path qw(make_path remove_tree);
 use File::Slurp::Shortcuts qw(slurp slurp_c write_file);
 use File::Temp qw(tempfile tempdir);
+use List::MoreUtils qw(uniq);
 use List::Util qw(first);
 use Log::Any::For::Builtins qw(system my_qx);
 use Module::Path qw(module_path);
-#use SHARYANTO::Dist::Util qw(packlist_for);
+use SHARYANTO::Dist::Util qw(list_dist_modules);
 use SHARYANTO::Proc::ChildError qw(explain_child_error);
 use String::ShellQuote;
 use version;
 
 sub _sq { shell_quote($_[0]) }
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 our %SPEC;
 
@@ -63,6 +64,17 @@ sub _build_lib {
 
     push @mods, @{ $self->{include} // [] };
 
+    for (@{ $self->{include_dist} // [] }) {
+        my @distmods = list_dist_modules($_);
+        if (@distmods) {
+            push @mods, @distmods;
+        } else {
+            push @mods, $_;
+        }
+    }
+
+    @mods = uniq(@mods);
+
     # filter excluded
     my @fmods;
   MOD:
@@ -149,7 +161,7 @@ $SPEC{fatten} = {
             pos => 1,
         },
         include => {
-            summary => 'Modules to include',
+            summary => 'Include extra modules',
             description => <<'_',
 
 When the tracing process fails to include a required module, you can add it
@@ -159,6 +171,18 @@ _
             schema => ['array*' => of => 'str*'],
             cmdline_aliases => { I => {} },
         },
+        include_dist => {
+            summary => 'Include extra modules',
+            description => <<'_',
+
+Just like the `include` option, but will include module as well as other modules
+from the same distribution. Module name must be the main module of the
+distribution. Will determine other modules from the `.packlist` file.
+
+_
+            schema => ['array*' => of => 'str*'],
+            cmdline_aliases => {},
+        },
         exclude => {
             summary => 'Modules to exclude',
             description => <<'_',
@@ -271,12 +295,18 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
 This distribution provides command-line utility called L<fatten>.
 
+=head2 TODO
+
+=over
+
+=back
+
 =head1 FUNCTIONS
 
 
@@ -300,11 +330,19 @@ When you don't want to include a pattern of modules, specify it here.
 
 =item * B<include> => I<array>
 
-Modules to include.
+Include extra modules.
 
 When the tracing process fails to include a required module, you can add it
 here.
 
+=item * B<include_dist> => I<array>
+
+Include extra modules.
+
+Just like the C<include> option, but will include module as well as other modules
+from the same distribution. Module name must be the main module of the
+distribution. Will determine other modules from the C<.packlist> file.
+
 =item * B<input_file>* => I<str>
 
 Path to input file (script to be packed).
